/*
   FOHDATA.LIB v1.3

     FOH v3.xx database access functions.
     For third party development of FOH add-ons.
     Compiled using large memory model.

   Copyright 1995,96 Scott Vermeersch.
*/

#include "fohdata.h"
#include <stdlib.h>
#include <stdio.h>
#include <share.h>
#include <io.h>
#include <conio.h>
#include <dos.h>
#include <string.h>

FILE *FOHDATA_Pointer;
int Open_FOHDATA (void);
int Close_FOHDATA (void);

int Open_FOHDATA (void)
{
  int count=0;
  char debug[14];
  FILE *df;

  while ((FOHDATA_Pointer=_fsopen("FOHDATA.DAT", "rb+", SH_DENYRW)) == NULL)
    {
    if (access ("FOHDATA.DAT", 0)) return NULL;
    if (count>10)
      {
      textcolor (WHITE);
      textbackground (BLUE);
      gotoxy (1,23);
      cprintf ("Waiting for Write access to %s...%d", "FOHDATA.DAT", count);
      }
    count++;
    delay (100);
    if (count>50)
      {
      cprintf ("\n\r\n\rAn ERROR has occurred.\n\r");
      cprintf ("File I/O write ERROR in FOHDATA.DAT.\n\r\n\r");
      exit (3);
      }
    }
  return 1;
}

int Close_FOHDATA (void)
{
  fclose (FOHDATA_Pointer);
  return 1;
}

long Read_FOHDATA_Header (FOH_Data_Header *Header)
{
long posistion;

  if (Open_FOHDATA ()==NULL) exit (3);
  fread (Header, sizeof (FOH_Data_Header), 1, FOHDATA_Pointer);
  posistion=ftell (FOHDATA_Pointer);
  if (strcmp (Header->Data_CRC, "FOH v3.xx R1 CRC"))
    {
    Close_FOHDATA ();
    return NULL;
    }
  else
    {
    Close_FOHDATA ();
    return posistion;
    }
}

long Write_FOHDATA_Header (FOH_Data_Header *Header)
{
  if (Open_FOHDATA ()==NULL) exit (3);
  if (strcmp (Header->Data_CRC, "FOH v3.xx R1 CRC"))
    {
    Close_FOHDATA ();
    return NULL;
    }

  fwrite (Header, sizeof (FOH_Data_Header), 1, FOHDATA_Pointer);
  Close_FOHDATA ();
  return ftell (FOHDATA_Pointer);
}

long Read_Record (long record, FOH_Player *Player)
{
  FOH_Data_Header Header;

  if (Read_FOHDATA_Header (&Header))
    {
    if (Open_FOHDATA ()==NULL) exit (3);
    if (fseek (FOHDATA_Pointer, Header.Offset_To_Data+record*Header.Data_Length, SEEK_SET)) exit (3);
    fread (Player, sizeof (FOH_Player), 1, FOHDATA_Pointer);
    Close_FOHDATA ();
    return Player->record;
    }
  return -1;
}

long Write_Record (long record, FOH_Player *Player)
{
  FOH_Data_Header Header;

  if (Read_FOHDATA_Header (&Header))
    {
    if (Player->experience>Header.Highest_Experience)
      {
      Header.Highest_Experience=Player->experience;
      Write_FOHDATA_Header (&Header);
      }
    if (Open_FOHDATA ()==NULL) exit (3);
    if (fseek (FOHDATA_Pointer, Header.Offset_To_Data+record*Header.Data_Length, SEEK_SET)) exit (3);
    fwrite (Player, sizeof (FOH_Player), 1, FOHDATA_Pointer);
    Close_FOHDATA ();
    return Player->record;
    }
  return -1;
}

long Write_Current_Record (FOH_Player *Player)
{
  FOH_Data_Header Header;

  if (Read_FOHDATA_Header (&Header))
    {
    if (Player->experience>Header.Highest_Experience)
      {
      Header.Highest_Experience=Player->experience;
      Write_FOHDATA_Header (&Header);
      }
    if (Open_FOHDATA ()==NULL) exit (3);
    if (fseek (FOHDATA_Pointer, Header.Offset_To_Data+Player->record*Header.Data_Length, SEEK_SET))
      exit (3);
    fwrite (Player, sizeof (FOH_Player), 1, FOHDATA_Pointer);
    Close_FOHDATA ();
    return Player->record;
    }
  return -1;
}

long Read_Current_Record (FOH_Player *Player)
{
  FOH_Data_Header Header;

  if (Read_FOHDATA_Header (&Header))
    {
    if (Player->experience>Header.Highest_Experience)
      {
      Header.Highest_Experience=Player->experience;
      Write_FOHDATA_Header (&Header);
      }
    if (Open_FOHDATA ()==NULL) exit (3);
    if (fseek (FOHDATA_Pointer, Header.Offset_To_Data+Player->record*Header.Data_Length, SEEK_SET))
      exit (3);
    fread (Player, sizeof (FOH_Player), 1, FOHDATA_Pointer);
    Close_FOHDATA ();
    return Player->record;
    }
  return NULL;
}

long Get_Record_Name (char *name, FOH_Player *Player)
{
  int Name_Length;
  long Record_Number;
  FOH_Data_Header Header;

  Name_Length=strlen (name);
  Read_FOHDATA_Header (&Header);
  Record_Number=0;

  do
    {
    Read_Record (Record_Number, Player);
    if (!strnicmp (name, Player->name, Name_Length)) return Player->record;
    Record_Number++;
    }
  while (Record_Number<Header.Number_Of_Records);

  return -1;
}

long Put_Record_Name (char *name, FOH_Player *Player)
{
  long Record_Number;
  FOH_Data_Header Header;

  Read_FOHDATA_Header (&Header);

  for (Record_Number=0; Record_Number<Header.Number_Of_Records; Record_Number++)
    {
    Read_Record (Record_Number, Player);
    if (!strcmpi (name, Player->name))
      {
      Write_Record (Record_Number, Player);
      return Player->record;
      }
    }
  return -1;
}

int Delete_Record (long record)
{
  FOH_Player Player;

  Read_Record (record, &Player);
  Player.deleted=1;
  Write_Record (record, &Player);
  return 1;
}

long Find_Deleted (void)
{
  long Record_Number;
  FOH_Player Player;
  FOH_Data_Header Header;

  Read_FOHDATA_Header (&Header);

  for (Record_Number=0; Record_Number<Header.Number_Of_Records; Record_Number++)
    {
    Read_Record (Record_Number, &Player);
    if (Player.deleted) return Record_Number;
    }
  return -1;
}

long Get_User_Record (char *name)
{
  long Record_Number;
  FOH_Player Player;
  FOH_Data_Header Header;

  Read_FOHDATA_Header (&Header);

  for (Record_Number=0; Record_Number<Header.Number_Of_Records; Record_Number++)
    {
    Read_Record (Record_Number, &Player);
    if (!strcmp (name, Player.player))
      {
      Read_Record (Record_Number, &Player);
      return Player.record;
      }
    }
  return -1;
}

long Add_Record (char *name, char *player_name, char *BBS_name)
{
  int count;
  long Record_Number;
  FOH_Player Player;
  FOH_Data_Header Header;

  if (!Read_FOHDATA_Header (&Header)) exit (3);

  if (Header.Number_Of_Records==0) Record_Number=0;
  if ((Record_Number=Find_Deleted ())==-1)
    {
    Record_Number=Header.Number_Of_Records;
    Header.Number_Of_Records++;
    }

  Write_FOHDATA_Header (&Header);

  Player.record=Record_Number;
  Player.deleted=0;
  Player.where=0;
  strcpy (Player.name,name);
  strcpy (Player.player,player_name);
  strcpy (Player.from,BBS_name);
  strcpy (Player.weapon,"Stick");
  strcpy (Player.armour,"Cloth");
  Player.level=0;
  Player.experience=10;
  Player.nextlevel=100;
  Player.coins=100;
  Player.coinbank=0;
  Player.artifact=0;
  Player.hitpoints=10;
  Player.maxhitpoints=10;
  Player.weapond=1;
  Player.weapons=5;
  Player.weaponb=0;
  Player.armourd=1;
  Player.armours=3;
  Player.armourb=0;
  Player.fights=15;
  Player.luck=0;
  Player.alive=1;

  for (count=0;count<10;count++)
    {
    Player.equipment [count]=0;
    Player.flags [count]=0;
    }

  Write_Record (Record_Number, &Player);
  return Record_Number;
}

long Find_Old (void)
{
  long Record_Number;
  FOH_Player Player;
  FOH_Data_Header Header;

  Read_FOHDATA_Header (&Header);

  for (Record_Number=0; Record_Number<Header.Number_Of_Records; Record_Number++)
    {
    Read_Record (Record_Number, &Player);
    if (Header.FOH_Date-Player.date>15) return Record_Number;
    }
  return -1;
}

int Write_FOH_Drop_File (int Node, FOH_Player *Player)
{
  FOH_Drop_Data DropData;
  FILE *Drop_Data_Pointer;
  char file[14];

  strcpy (DropData.player,Player->player);
  strcpy (DropData.name,Player->name);
  strcpy (DropData.from,Player->from);
  strcpy (DropData.weapon,Player->weapon);
  strcpy (DropData.armour,Player->armour);
  DropData.fights=Player->fights;
  DropData.level=Player->level;
  DropData.weapond=Player->weapond;
  DropData.weapons=Player->weapons;
  DropData.weaponb=Player->weaponb;
  DropData.armourd=Player->armourd;
  DropData.armours=Player->armours;
  DropData.armourb=Player->armourb;
  DropData.experience=Player->experience;
  DropData.nextlevel=Player->nextlevel;
  DropData.coins=Player->coins;
  DropData.coinbank=Player->coinbank;
  DropData.artifact=Player->artifact;
  DropData.hitpoints=Player->hitpoints;
  DropData.maxhitpoints=Player->maxhitpoints;
  DropData.luck=Player->luck;
  DropData.alive=1;

  sprintf (file, "FOH%d.SYS", Node);
  if ((Drop_Data_Pointer=_fsopen (file, "wb", SH_DENYRW)) == NULL) exit (3);
  fwrite (&DropData, sizeof DropData, 1, Drop_Data_Pointer);
  fclose (Drop_Data_Pointer);
  return 1;
}

int Read_FOH_Drop_File (int Node, FOH_Player *Player)
{
  FOH_Drop_Data DropData;
  FILE *Drop_Data_Pointer;
  char file[14];

  sprintf (file, "FOH%d.SYS", Node);
  if ((Drop_Data_Pointer=_fsopen (file, "rb", SH_DENYRW)) == NULL) exit (3);
  fread (&DropData, sizeof DropData, 1, Drop_Data_Pointer);
  fclose (Drop_Data_Pointer);

  strcpy (Player->player,DropData.player);
  strcpy (Player->name,DropData.name);
  strcpy (Player->from,DropData.from);
  strcpy (Player->weapon,DropData.weapon);
  strcpy (Player->armour,DropData.armour);
  Player->fights=DropData.fights;
  Player->level=DropData.level;
  Player->weapond=DropData.weapond;
  Player->weapons=DropData.weapons;
  Player->weaponb=DropData.weaponb;
  Player->armourd=DropData.armourd;
  Player->armours=DropData.armours;
  Player->armourb=DropData.armourb;
  Player->experience=DropData.experience;
  Player->nextlevel=DropData.nextlevel;
  Player->coins=DropData.coins;
  Player->coinbank=DropData.coinbank;
  Player->artifact=DropData.artifact;
  Player->hitpoints=DropData.hitpoints;
  Player->maxhitpoints=DropData.maxhitpoints;
  Player->luck=DropData.luck;
  Player->alive=DropData.alive;

  return 1;
}

int Write_Transfer_File (FOH_Player *Player)
{
  FOH_Drop_Data DropData;
  FILE *Transfer_Pointer;

  strcpy (DropData.player,Player->player);
  strcpy (DropData.name,Player->name);
  strcpy (DropData.from,Player->from);
  strcpy (DropData.weapon,Player->weapon);
  strcpy (DropData.armour,Player->armour);
  DropData.fights=Player->fights;
  DropData.level=Player->level;
  DropData.weapond=Player->weapond;
  DropData.weapons=Player->weapons;
  DropData.weaponb=Player->weaponb;
  DropData.armourd=Player->armourd;
  DropData.armours=Player->armours;
  DropData.armourb=Player->armourb;
  DropData.experience=Player->experience;
  DropData.nextlevel=Player->nextlevel;
  DropData.coins=Player->coins;
  DropData.coinbank=Player->coinbank;
  DropData.artifact=Player->artifact;
  DropData.hitpoints=Player->hitpoints;
  DropData.maxhitpoints=Player->maxhitpoints;
  DropData.luck=Player->luck;
  DropData.alive=1;

  if ((Transfer_Pointer=_fsopen ("FOH.SYS", "wb", SH_DENYRW)) == NULL) return 0;
  fwrite (&DropData, sizeof DropData, 1, Transfer_Pointer);
  fclose (Transfer_Pointer);
  return 1;
}

int Read_Transfer_File (FOH_Player *Player)
{
  FOH_Drop_Data DropData;
  FILE *Transfer_Pointer;

  if ((Transfer_Pointer=_fsopen ("FOH.SYS", "rb", SH_DENYRW)) == NULL) return 0;
  fread (&DropData, sizeof DropData, 1, Transfer_Pointer);
  fclose (Transfer_Pointer);

  strcpy (Player->player,DropData.player);
  strcpy (Player->name,DropData.name);
  strcpy (Player->from,DropData.from);
  strcpy (Player->weapon,DropData.weapon);
  strcpy (Player->armour,DropData.armour);
  Player->fights=DropData.fights;
  Player->level=DropData.level;
  Player->weapond=DropData.weapond;
  Player->weapons=DropData.weapons;
  Player->weaponb=DropData.weaponb;
  Player->armourd=DropData.armourd;
  Player->armours=DropData.armours;
  Player->armourb=DropData.armourb;
  Player->experience=DropData.experience;
  Player->nextlevel=DropData.nextlevel;
  Player->coins=DropData.coins;
  Player->coinbank=DropData.coinbank;
  Player->artifact=DropData.artifact;
  Player->hitpoints=DropData.hitpoints;
  Player->maxhitpoints=DropData.maxhitpoints;
  Player->luck=DropData.luck;
  Player->alive=DropData.alive;

  return 1;
}

long Get_Enemy (int level, int where, FOH_Enemy *Enemy)
{
  int count;
  long post;
  long check;

  if ((FOHDATA_Pointer=_fsopen("ENEMY.LST", "rb", SH_DENYRW)) == NULL) return NULL;

  if (where==21)
    {
    if (fseek (FOHDATA_Pointer, 4999l*sizeof (FOH_Enemy), SEEK_SET)) exit (3);
    fread (Enemy, sizeof (FOH_Enemy), 1, FOHDATA_Pointer);
    fclose (FOHDATA_Pointer);
    return 4999;
    }

  if (where==18)
    {
    if (fseek (FOHDATA_Pointer, (5000l+level)*sizeof (FOH_Enemy), SEEK_SET)) exit (3);
    fread (Enemy, sizeof (FOH_Enemy), 1, FOHDATA_Pointer);
    fclose (FOHDATA_Pointer);
    return 5000l+level;
    }

  if (where==30)
    {
    count=1000;
    while (1)
      {
      check=random (count)+4000;
      if (fseek (FOHDATA_Pointer, check*sizeof (FOH_Enemy), SEEK_SET)) exit (3);
      fread (Enemy, sizeof (FOH_Enemy), 1, FOHDATA_Pointer);
      if (strlen (Enemy->name)>1)
	{
	fclose (FOHDATA_Pointer);
	return check;
	}

      count--;
      if (count<1)
	{
	fclose (FOHDATA_Pointer);
	return -1;
	}
      }
    }

  if (where==26) post=level*50;
  if (where==27) post=level*50+1000;
  if (where==28) post=level*50+2000;
  if (where==29) post=level*50+3000;
  count=50;

  while (1)
    {
    check=post+random (count);
    if (fseek (FOHDATA_Pointer, check*sizeof (FOH_Enemy), SEEK_SET)) exit (3);
    fread (Enemy, sizeof (FOH_Enemy), 1, FOHDATA_Pointer);
    if (strlen (Enemy->name)>1)
      {
      fclose (FOHDATA_Pointer);
      return check;
      }

    count--;
    if (count<1)
      {
      fclose (FOHDATA_Pointer);
      return -1;
      }
    }
}

long Read_Enemy (long place, FOH_Enemy *Enemy)
{
  if ((FOHDATA_Pointer=_fsopen("ENEMY.LST", "rb", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Enemy), SEEK_SET)) exit (3);
  fread (Enemy, sizeof (FOH_Enemy), 1, FOHDATA_Pointer);
  if (strlen (Enemy->name)>1)
    {
    fclose (FOHDATA_Pointer);
    return 1;
    }
  else
    {
    fclose (FOHDATA_Pointer);
    return 0;
    }
}

long Write_Enemy (long place, FOH_Enemy *Enemy)
{
  if ((FOHDATA_Pointer=_fsopen("ENEMY.LST", "rb+", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Enemy), SEEK_SET)) exit (3);
  fwrite (Enemy, sizeof (FOH_Enemy), 1, FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);

  return ftell (FOHDATA_Pointer);
}

int Read_Bin (Node_Info *BIN, int node)
{
  char file[14];

  sprintf (file, "NODE%d.BIN", node);
  if (access (file, 0)) return 0;

  if ((FOHDATA_Pointer=_fsopen(file, "rb", SH_DENYRW)) == NULL) return 0;
  fread (BIN,sizeof (Node_Info),1,FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);
  return 1;
}

int Write_Bin (Node_Info *BIN, int node)
{
  char file[14];

  sprintf (file, "NODE%d.BIN", node);

  if ((FOHDATA_Pointer=_fsopen(file, "wb", SH_DENYRW)) == NULL) return 0;
  fwrite (BIN,sizeof (Node_Info),1,FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);
  return 1;
}

long Read_House_Type (long place, FOH_House_Type *House)
{
  if (place<0 || place>14) return 0;
  if ((FOHDATA_Pointer=_fsopen("HOUSE.LST", "rb", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_House_Type), SEEK_SET)) exit (3);
  fread (House, sizeof (FOH_House_Type), 1, FOHDATA_Pointer);
  if (strlen (House->type)>1)
    {
    fclose (FOHDATA_Pointer);
    return 1;
    }
  else
    {
    fclose (FOHDATA_Pointer);
    return 0;
    }
}

long Write_House_Type (long place, FOH_House_Type *House)
{
  if (place<0 || place>14) return 0;
  if ((FOHDATA_Pointer=_fsopen("HOUSE.LST", "rb+", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_House_Type), SEEK_SET)) exit (3);
  fwrite (House, sizeof (FOH_House_Type), 1, FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);

  return ftell (FOHDATA_Pointer);
}

int Read_Player_House (FOH_House *House, FOH_Player *Player)
{
  char file[14];

  sprintf (file, "HS%ld.DAT", Player->record);
  if ((FOHDATA_Pointer=_fsopen(file, "rb+", SH_DENYRW)) == NULL) return 0;
  fread (House,sizeof (FOH_House),1,FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);
  return 1;
}

int Write_Player_House (FOH_House *House, FOH_Player *Player)
{
  char file[14];

  sprintf (file, "HS%ld.DAT", Player->record);
  if ((FOHDATA_Pointer=_fsopen(file, "wb", SH_DENYRW)) == NULL) return 0;
  fwrite (House,sizeof (FOH_House),1,FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);
  return 1;
}

int Read_House (char *file, FOH_House *House)
{
  if ((FOHDATA_Pointer=_fsopen(file, "rb", SH_DENYRW)) == NULL) return 0;
  fread (House, sizeof (FOH_House), 1, FOHDATA_Pointer);
  if (strlen (House->name)>1)
    {
    fclose (FOHDATA_Pointer);
    return 1;
    }
  else
    {
    fclose (FOHDATA_Pointer);
    return 0;
    }
}

int Write_House (char *file, FOH_House *House)
{
  if ((FOHDATA_Pointer=_fsopen(file, "wb", SH_DENYRW)) == NULL) return 0;
  fwrite (House, sizeof (FOH_House), 1, FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);

  return 1;
}

long Read_Armour (long place, FOH_Armour *Armour)
{
  if ((FOHDATA_Pointer=_fsopen("ARMOUR.LST", "rb", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Armour), SEEK_SET)) exit (3);
  fread (Armour, sizeof (FOH_Armour), 1, FOHDATA_Pointer);
  if (strlen (Armour->armour)>1)
    {
    fclose (FOHDATA_Pointer);
    return 1;
    }
  else
    {
    fclose (FOHDATA_Pointer);
    return 0;
    }
}

long Write_Armour (long place, FOH_Armour *Armour)
{
  if ((FOHDATA_Pointer=_fsopen("ARMOUR.LST", "rb+", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Armour), SEEK_SET)) exit (3);
  fwrite (Armour, sizeof (FOH_Armour), 1, FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);

  return ftell (FOHDATA_Pointer);
}

long Read_Weapon (long place, FOH_Weapon *Weapon)
{
  if ((FOHDATA_Pointer=_fsopen("WEAPON.LST", "rb", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Weapon), SEEK_SET)) exit (3);
  fread (Weapon, sizeof (FOH_Weapon), 1, FOHDATA_Pointer);
  if (strlen (Weapon->weapon)>1)
    {
    fclose (FOHDATA_Pointer);
    return 1;
    }
  else
    {
    fclose (FOHDATA_Pointer);
    return 0;
    }
}

long Write_Weapon (long place, FOH_Weapon *Weapon)
{
  if ((FOHDATA_Pointer=_fsopen("WEAPON.LST", "rb+", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Weapon), SEEK_SET)) exit (3);
  fwrite (Weapon, sizeof (FOH_Weapon), 1, FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);

  return ftell (FOHDATA_Pointer);
}

long Read_Magic (long place, FOH_Magic *Magic)
{
  if ((FOHDATA_Pointer=_fsopen("MWORDS.LST", "rb", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Magic), SEEK_SET)) exit (3);
  fread (Magic, sizeof (FOH_Magic), 1, FOHDATA_Pointer);
  if (strlen (Magic->magic)>1)
    {
    fclose (FOHDATA_Pointer);
    return 1;
    }
  else
    {
    fclose (FOHDATA_Pointer);
    return 0;
    }
}

long Write_Magic (long place, FOH_Magic *Magic)
{
  if ((FOHDATA_Pointer=_fsopen("MWORDS.LST", "rb+", SH_DENYRW)) == NULL) return 0;
  if (fseek (FOHDATA_Pointer, place*sizeof (FOH_Magic), SEEK_SET)) exit (3);
  fwrite (Magic, sizeof (FOH_Magic), 1, FOHDATA_Pointer);
  fclose (FOHDATA_Pointer);

  return ftell (FOHDATA_Pointer);
}

int Read_Magic_Name (char *name, FOH_Magic *Magic)
{
  if (strlen (name)<1) return 0;
  if ((FOHDATA_Pointer=_fsopen("MWORDS.LST", "rb", SH_DENYRW)) == NULL) return 0;
  while (!feof (FOHDATA_Pointer))
    {
    fread (Magic, sizeof (FOH_Magic), 1, FOHDATA_Pointer);
    if (!strcmp (name, Magic->magic))
      {
      fclose (FOHDATA_Pointer);
      return 1;
      }
    }
  fclose (FOHDATA_Pointer);
  return 0;
}

