/*
   FOH FOHDATA.LIB header file.

   Include in FOH add-ons and utilities compiled with FOHDATA.LIB.
   The FOHDATA.LIB is compiled using the large memory model.

   Copyright 1996 Scott Vermeersch.
*/

#define MAX 4000000000
#define IMAX 30000
#define MAXPLAY 100
#define INN 10
#define NODES 20

//Equipment Defines.

//#define open   0   //Unused.
#define TENTS  1   //Number of tents.
#define CABIN  2   //If true, has cabin.
#define PARKA  3   //If true, can hunt in North area.
#define WATER  4   //If true, can hunt in West area.
#define BOATS  5   //If true, can hunt in Secret area.
#define PICKS  6   //Number of Lock picks.
#define COMPA  7   //If true, has compass.
#define CALLS  8   //If true, has Call.
//#define open   9   //Unused.

//Flag defines

#define GYPSY  0   //If true, seen Gypsies, reset each day.
#define BANK   1   //If true, robbed bank.
#define MONEY  2   //Reward offered to kill.
#define OVRLRD 4   //1 OverLord; 2 Alchemist;
#define GENDER 5   //Gender of Player. 0=male 1=female
#define GMBL   6   //Number of Gambles, reset each day.
#define LOAN   7   //Amount of loan.
#define RENT   8   //Amount of Rent.
#define PDAY   9   //If true, played today, reset each day.

#ifdef __cplusplus
extern "C" {
#endif
long Read_FOHDATA_Header (struct FOH_Data_Header *);
long Write_FOHDATA_Header (struct FOH_Data_Header *);
long Read_Record (long, struct FOH_Player *);
long Write_Record (long, struct FOH_Player *);
long Write_Current_Record (struct FOH_Player *);
long Read_Current_Record (struct FOH_Player *);
long Get_Record_Name (char *, struct FOH_Player *);
long Put_Record_Name (char *, struct FOH_Player *);
int Delete_Record (long);
long Find_Deleted (void);
int Init_FOH_Player (struct FOH_Player *);
long Get_User_Record (char *);
long Add_Record (char *, char *, char *);
long Find_Old (void);
int Write_FOH_Drop_File (int, struct FOH_Player *);
int Read_FOH_Drop_File (int, struct FOH_Player *);
int Write_Transfer_File (struct FOH_Player *);
int Read_Transfer_File (struct FOH_Player *);
long Get_Enemy (int, int, struct FOH_Enemy *);
long Read_Enemy (long, struct FOH_Enemy *);
long Write_Enemy (long, struct FOH_Enemy *);
int Read_Bin (struct Node_Info *, int node);
int Write_Bin (struct Node_Info *, int node);
long Read_House_Type (long, struct FOH_House_Type *);
long Write_House_Type (long, struct FOH_House_Type *);
int Read_Player_House (struct FOH_House *, struct FOH_Player *);
int Write_Player_House (struct FOH_House *, struct FOH_Player *);
int Read_House (char *, struct FOH_House *);
int Write_House (char *, struct FOH_House *);
long Read_Armour (long, struct FOH_Armour *);
long Write_Armour (long, struct FOH_Armour *);
long Read_Weapon (long, struct FOH_Weapon *);
long Write_Weapon (long, struct FOH_Weapon *);
long Read_Magic (long, struct FOH_Magic *);
long Write_Magic (long, struct FOH_Magic *);
int Read_Magic_Name (char *, struct FOH_Magic *);

typedef struct FOH_Player
{
  long record;
  int deleted;
  char player[81];                  /*Players name from BBS                 */
  char name[21];                    /*Players name for FOH                  */
  int  where;                       /*Present Location                      */
  char from[20];                    /*Home BBS                              */
  char weapon[20];                  /*Name of Weapon                        */
  char armour[20];                  /*Name of Armour                        */
  int fights;                       /*Enemy fights		            */
  int level;                        /*Present Level                         */
  int weapond;                      /*Weapons number of dice                */
  int weapons;                      /*Weapons dice # of sides               */
  int weaponb;                      /*Weapons bonus points                  */
  int armourd;                      /*Armours number of dice                */
  int armours;                      /*Armours dice # of sides               */
  int armourb;                      /*Armours bonus points                  */
  unsigned long experience;         /*Expierience of Player                 */
  unsigned long nextlevel;          /*Amount needed for next level          */
  unsigned long coins;              /*Coins on hand                         */
  unsigned long coinbank;           /*Coins in Bank                         */
  int artifact;                     /*Number of artifacts for trade         */
  long hitpoints;                   /*Present Hitpoints                     */
  long maxhitpoints;                /*Maximum Hitpoints                     */
  int pfight;                       /*Players fight for day                 */
  int luck;                         /*Luck of Player                        */
  int flags [10];                   /*See flag defines                      */
  int equipment [10];               /*see equipment defines                 */
  int alive;                        /*Alive=1 Dead=0 Seen master=3          */
  int date;                         /*Number of day lasted played           */
};

typedef struct Node_Info
{
  int  node;
  int  status;
  char name[21];
  int  level;
  long record;
  int  attacked;
  int  paged;
  int  inchat;
};

typedef struct FOH_Data_Header
{
  int Data_Version;
  int Day_Of_Month;
  int FOH_Date;
  long Offset_To_Data;
  long Data_Length;
  long Overlord_Record;
  long Number_Of_Records;
  unsigned long Highest_Experience;
  char Data_CRC[20];
};

typedef struct FOH_Drop_Data
{
  char player[81];                  /*Players name from BBS                 */
  char name[21];                    /*Players name for FOH                  */
  char from[20];                    /*Home BBS                              */
  char weapon[20];                  /*Name of Weapon                        */
  char armour[20];                  /*Name of Armour                        */
  int fights;                       /*Enemy fights		          */
  int level;                        /*Present Level  0-19                   */
  int weapond;                      /*Weapons number of dice                */
  int weapons;                      /*Weapons dice # of sides               */
  int weaponb;                      /*Weapons bonus points                  */
  int armourd;                      /*Armours number of dice                */
  int armours;                      /*Armours dice # of sides               */
  int armourb;                      /*Armours bonus points                  */
  unsigned long experience;         /*Expierience of Player                 */
  unsigned long nextlevel;          /*Amount needed for next level          */
  unsigned long coins;              /*Coins on hand                         */
  unsigned long coinbank;           /*Coins in Bank                         */
  int artifact;                     /*Number of artifacts for trade         */
  long hitpoints;                   /*Present Hitpoints                     */
  long maxhitpoints;                /*Maximum Hitpoints                     */
  int luck;                         /*Luck of Player                        */
  int alive;                        /*Player alive=1, player dead=0         */
};

typedef struct FOH_Enemy
{
  char name [20];                /*  Overlord's name           */
  char weapon [20];              /*  Overlord's weapon name    */
  char effect;                   /*  Magic class effect        */
  long experience;               /*  experience given          */
  long coins;                    /*  coins given	             */
  int weapond;                   /*  Weapon die #              */
  int weapons;                   /*  Weapon die side  	     */
  int armourd;                   /*  Armour die #              */
  int armours;                   /*  Armour die side           */
  long hitpoint;                 /*  enemy hitpoints           */
};

typedef struct FOH_Armour
{
  char armour [20];              /*  Armour name         */
  int armourd;                   /*  Armour # die        */
  int armours;                   /*  Armour # die sides  */
  int armourb;                   /*  Armour bonus        */
  long cost;                     /*  Armour cost         */
};

typedef struct FOH_Weapon
{
  char weapon [20];              /*  weapon name         */
  int weapond;                   /*  Weapon # die        */
  int weapons;                   /*  Weapon # die sides  */
  int weaponb;                   /*  Weapon bonus        */
  long cost;                     /*  weapon cost         */
};

typedef struct FOH_House
{
  long owner;
  char name [24];
  char type [24];
  int rent;
  int combo;
  int dogs;
  int basedef;
  unsigned long coins;
  int flags [10];
  char weapon [10][20];
  int weapond [10];
  int weapons [10];
  int weaponb [10];
  char armour [10][20];
  int armourd [10];
  int armours [10];
  int armourb [10];
};

typedef struct FOH_House_Type
{
  char type [24];
  char desc [4][80];
  int rent;
  int dogs;
  int basedef;
  int flags [10];
};

typedef struct FOH_Magic
{
  char magic [20];
  long damage;
  int  effect;
};

#ifdef __cplusplus
}
#endif
